%global _description\
Schemas for messages sent by Copr project, as described on \
fedora-messaging documentation page \
https://fedora-messaging.readthedocs.io/en/latest/messages.html#schema \
\
Package also provides several convenience methods for working with \
copr messages.

Name:       copr-messaging
Version:    1.1
Release:    1.20250620081448108136.main.11.ga39dafd39%{?dist}
Summary:    Abstraction for Copr messaging listeners/publishers

License:    GPL-2.0-or-later
URL:        https://github.com/fedora-copr/copr

# Source is created by:
# git clone %%url && cd copr
# tito build --tgz --tag %%name-%%version-%%release
Source0:    copr-messaging-git-0.d8c7470.tar.gz

BuildArch:  noarch

Requires:      wget


BuildRequires: asciidoc
BuildRequires: libxslt
BuildRequires: util-linux

BuildRequires: python3-copr-common
BuildRequires: python3-devel
BuildRequires: python3-fedora-messaging
BuildRequires: python3-pytest
BuildRequires: python3-setuptools
BuildRequires: python3-sphinx

%description %_description


%package -n python3-%name
Summary: %summary
Provides: %name = %version
%{?python_provide:%python_provide python3-%{name}}

Requires: python3-copr-common
Requires: python3-fedora-messaging

%description -n python3-%name %_description

%package -n python3-%name-doc
Summary: Code documentation for copr messaging

%description -n python3-%name-doc %_description

This package contains documentation for copr-messaging.


%prep
%setup -q -n copr-messaging-git-0.d8c7470


%build
%py3_build
PYTHONPATH=${PWD} sphinx-build-3 docs html
rm -rf html/.{doctrees,buildinfo}


%install
%py3_install


%check
./run_tests.sh -vv


%files -n python3-%name
%license LICENSE
%doc README.md
%python3_sitelib/copr_messaging
%python3_sitelib/copr_messaging*egg-info

%files -n python3-%name-doc
%license LICENSE
%doc html


%changelog
* Fri Jun 20 2025 Packit <hello@packit.dev> - 1.1-1.20250620081448108136.main.11.ga39dafd39
- doc: stop using deprecated get_html_theme_path funciton (Jakub Kadlcik)
- frontend: disable network when crearing a new fedora review project (Jakub Kadlcik)
- frontend: hide excessive CoprDirs under a details tag (Jakub Kadlcik)
- backend: make PULP work more verbose in logs (Pavel Raiskup)
- backend: fix waiting for Pulp copr_base repository (Jakub Kadlcik)
- Create one repository version and publication per chroot (Dennis Kliban)
- remove license classifier (Miroslav Suchý)
- common: modernize specfile using pyproject macro (Miroslav Suchý)
- backend: use real condition as assert can be removed in compiled code (Miroslav Suchý)
- backend: optimize copr_log_hitcounter for memory (Miroslav Suchý)
- backend: optimize copr_log_hitcounter for memory (Miroslav Suchý)
- Automatic commit of package [copr-backend] release [2.5-1]. (Jakub Kadlcik)
- backend: pulp in production and STG uses a bit different URLs (Jakub Kadlcik)
- Correct typo in main.py (rxguy)
- backend: add script to migrate pulp.json to Pulp labels (Jakub Kadlcik)
- backend: add function to get pulp object based on its href (Jakub Kadlcik)
- Update user_documentation.rst (Luiz Miguel)
- backend: strip leading zeros from the build ID (Jakub Kadlcik)
- backend: pass build ID to upload_build_results (Jakub Kadlcik)
- frontend: fix local builds in Pulp projects (Jakub Kadlcik)
- backend: more log "checkpoints" for build worker (Pavel Raiskup)
- backend: fix typo in dkilban's name, sorry (Pavel Raiskup)
- Automatic commit of package [copr-backend] release [2.4-1]. (Pavel Raiskup)
- Uses build_id to find packages for removal (Dennis Kliban)
- Adds build_id pulp_label to RPMs uploaded to Pulp. (Dennis Kliban)
- rpmbuild: deduplicate two methods (Pavel Raiskup)
- Use ThreadPoolExecutor to parallelize RPM uploads to Pulp. (Dennis Kliban)
- docs: drop pulp playbooks from RPM releasing manual (Jiri Kyjovsky)
- Add AlmaLinux logo (Jonathan Wright)
- Update centos logo (Jonathan Wright)
- frontend: fix one pagure-events' traceback (Pavel Raiskup)
- frontend: use the new BeautifulSoup find_all() method (Pavel Raiskup)
- frontend: drop the duplicit session.commit() call (Pavel Raiskup)
- frontend: fix autoflushing warnings, take #2 (Pavel Raiskup)
- frontend: models_committed has been moved in sqlalchemy (Pavel Raiskup)
- frontend: fix SAWarnings about autoflush (Jiri Kyjovsky)
- rpmbuild: make sure we use the latest dist-git-client (Pavel Raiskup)
- backend: drop the novaclient dependency (Pavel Raiskup)
- releng: release clients into all EPEL chroots (Pavel Raiskup)
- frontend: fix typo in logging message (Pavel Raiskup)
- frontend: pagure-events fail for "dots" in copr.name (Pavel Raiskup)
- doc: add release notes for copr update (Jiri Kyjovsky)
- frontend: treat malformed task_id in backend_general (Jiri Kyjovsky)
- frontend: log the user who removes a project (Pavel Raiskup)
- Automatic commit of package [copr-backend] release [2.3-1]. (Pavel Raiskup)
- backend: lighttpd-filesystem provides group(lighttpd) on F42+ (Pavel Raiskup)
- Automatic commit of package [copr-backend] release [2.2-1]. (Pavel Raiskup)
- Add sysusers.d config file to allow rpm to create users/groups automatically (Miroslav Suchý)

* Tue Mar 25 2025 Pavel Raiskup <praiskup@redhat.com> 1.1-1
- fix FTBFS caused by sphinx config
- add missing @propery decorators

* Wed Oct 02 2024 Jiri Kyjovsky <j1.kyjovsky@gmail.com> 1.0-1
- Set chroot message severity to DEBUG
- One-line descriptions should be the summary

* Fri Mar 01 2024 Pavel Raiskup <praiskup@redhat.com> 0.11-1
- handle namespaced usernames
- set the agent_name and usernames properties

* Mon May 22 2023 Jakub Kadlcik <frostyx@email.cz> 0.10-1
- Derive all message classes from _CoprMessage

* Wed Mar 22 2023 Jiri Kyjovsky <j1.kyjovsky@gmail.com> 0.9-1
- Add app_name property to _CoprMessage base class
* Tue Jan 24 2023 Jakub Kadlcik <frostyx@email.cz> 0.8-1
- Use SPDX license

* Sat Nov 26 2022 Jakub Kadlcik <frostyx@email.cz> 0.7-1
- move to GitHub home page
- sync tooling with other sub-projects

* Tue Jun 21 2022 Jakub Kadlcik <frostyx@email.cz> 0.6-1
- Adapt to the changed stomppy API

* Mon Nov 09 2020 Jakub Kadlcik <frostyx@email.cz> 0.5-1
- explicitely requires python3-setuptools
- all: run pytest with -vv in package build
- pylint: sync all the pylintrc files
- pylint: run pylint in all run*tests.sh files

* Thu Oct 03 2019 Pavel Raiskup <praiskup@redhat.com> 0.4-1
- rename 'stomp_consumer' module to 'stomp'
- fix macros in comments

* Thu Jul 25 2019 Pavel Raiskup <praiskup@redhat.com> 0.3-1
- mention how to create Source0 tarball

* Wed Jul 24 2019 Pavel Raiskup <praiskup@redhat.com> 0.2-1
- apply review fixes (by Silvie)

* Wed Jul 17 2019 Pavel Raiskup <praiskup@redhat.com> 0.1-1
- copr_messaging: new package for working with copr messages
